diff --git a/data/gui/racesetup.stkgui b/data/gui/racesetup.stkgui
index b57557729..e8ab92867 100644
--- a/data/gui/racesetup.stkgui
+++ b/data/gui/racesetup.stkgui
@@ -13,7 +13,7 @@
-
+
diff --git a/data/gui/story_mode_new.stkgui b/data/gui/story_mode_new.stkgui
index cd6e4f6ef..f910288ba 100644
--- a/data/gui/story_mode_new.stkgui
+++ b/data/gui/story_mode_new.stkgui
@@ -10,7 +10,7 @@
-
+
diff --git a/data/gui/track_info_dialog.stkgui b/data/gui/track_info_dialog.stkgui
index 29a8751c4..68353008d 100644
--- a/data/gui/track_info_dialog.stkgui
+++ b/data/gui/track_info_dialog.stkgui
@@ -57,7 +57,7 @@
-
diff --git a/src/guiengine/engine.cpp b/src/guiengine/engine.cpp
index 268670882..ce1c9dbaa 100644
--- a/src/guiengine/engine.cpp
+++ b/src/guiengine/engine.cpp
@@ -473,8 +473,8 @@ namespace GUIEngine
this ribbon can have.
\n
- \subsection prop18 PROP_WARP_AROUND
- Name in XML files: \c "warp_around"
+ \subsection prop18 PROP_WRAP_AROUND
+ Name in XML files: \c "wrap_around"
Currently used for spinners only. Value can be "true" or "false"
diff --git a/src/guiengine/event_handler.cpp b/src/guiengine/event_handler.cpp
index 50aff798b..8a12a9225 100644
--- a/src/guiengine/event_handler.cpp
+++ b/src/guiengine/event_handler.cpp
@@ -436,7 +436,7 @@ void EventHandler::navigateUp(const int playerID, Input::InputType type, const b
{
if (NAVIGATION_DEBUG)
{
- std::cout << "EventHandler::navigateUp : warp around, selecting the last widget\n";
+ std::cout << "EventHandler::navigateUp : wrap around, selecting the last widget\n";
}
// select the last widget
@@ -560,7 +560,7 @@ void EventHandler::navigateDown(const int playerID, Input::InputType type, const
if (!found)
{
- if (NAVIGATION_DEBUG) std::cout << "Navigating down : warp around\n";
+ if (NAVIGATION_DEBUG) std::cout << "Navigating down : wrap around\n";
// select the first widget
Widget* firstWidget = NULL;
diff --git a/src/guiengine/screen_loader.cpp b/src/guiengine/screen_loader.cpp
index 2b7a6e1b0..9aa48fe93 100644
--- a/src/guiengine/screen_loader.cpp
+++ b/src/guiengine/screen_loader.cpp
@@ -215,7 +215,7 @@ if(prop_name != NULL) widget.m_properties[prop_flag] = core::stringc(prop_name).
READ_PROPERTY(extend_label, PROP_EXTEND_LABEL);
READ_PROPERTY(label_location, PROP_LABELS_LOCATION);
READ_PROPERTY(max_rows, PROP_MAX_ROWS);
- READ_PROPERTY(warp_around, PROP_WARP_AROUND);
+ READ_PROPERTY(wrap_around, PROP_WRAP_AROUND);
#undef READ_PROPERTY
const wchar_t* text = xml->getAttributeValue( L"text" );
diff --git a/src/guiengine/widget.hpp b/src/guiengine/widget.hpp
index b860a7db7..b2415910e 100644
--- a/src/guiengine/widget.hpp
+++ b/src/guiengine/widget.hpp
@@ -100,7 +100,7 @@ namespace GUIEngine
PROP_EXTEND_LABEL,
PROP_LABELS_LOCATION,
PROP_MAX_ROWS,
- PROP_WARP_AROUND
+ PROP_WRAP_AROUND
};
bool isWithinATextBox();
diff --git a/src/guiengine/widgets/model_view_widget.cpp b/src/guiengine/widgets/model_view_widget.cpp
index 8f6b70141..f716aeb98 100644
--- a/src/guiengine/widgets/model_view_widget.cpp
+++ b/src/guiengine/widgets/model_view_widget.cpp
@@ -110,7 +110,7 @@ void ModelViewWidget::update(float delta)
else if (m_rotation_mode == ROTATE_TO)
{
// check if we should rotate clockwise or counter-clockwise to reach the target faster
- // (taking warp-arounds into account)
+ // (taking wrap-arounds into account)
const int angle_distance_from_end = (int)(360 - angle);
const int target_distance_from_end = (int)(360 - angle);
diff --git a/src/guiengine/widgets/ribbon_widget.cpp b/src/guiengine/widgets/ribbon_widget.cpp
index eee870b72..88ac27f43 100644
--- a/src/guiengine/widgets/ribbon_widget.cpp
+++ b/src/guiengine/widgets/ribbon_widget.cpp
@@ -479,7 +479,7 @@ EventPropagation RibbonWidget::rightPressed(const int playerID)
}
}
- // if we reached a filler item, move again (but don't warp)
+ // if we reached a filler item, move again (but don't wrap)
if (getSelectionIDString(playerID) == RibbonWidget::NO_ITEM_ID)
{
if (m_selection[playerID] + 1 < m_children.size())
@@ -519,7 +519,7 @@ EventPropagation RibbonWidget::leftPressed(const int playerID)
}
}
- // if we reached a filler item, move again (but don't warp)
+ // if we reached a filler item, move again (but don't wrap)
if (getSelectionIDString(playerID) == RibbonWidget::NO_ITEM_ID)
{
if (m_selection[playerID] > 0) leftPressed(playerID);
diff --git a/src/guiengine/widgets/spinner_widget.cpp b/src/guiengine/widgets/spinner_widget.cpp
index 7763e8b86..36757ddb4 100644
--- a/src/guiengine/widgets/spinner_widget.cpp
+++ b/src/guiengine/widgets/spinner_widget.cpp
@@ -58,7 +58,7 @@ void SpinnerWidget::add()
std::string min_s = m_properties[PROP_MIN_VALUE];
std::string max_s = m_properties[PROP_MAX_VALUE];
- m_warp_around = (m_properties[PROP_WARP_AROUND] == "true");
+ m_wrap_around = (m_properties[PROP_WRAP_AROUND] == "true");
if (min_s.size() > 0)
{
@@ -244,7 +244,7 @@ EventPropagation SpinnerWidget::rightPressed(const int playerID)
{
setValue(m_value+1);
}
- else if (m_warp_around)
+ else if (m_wrap_around)
{
setValue(m_min);
}
@@ -266,7 +266,7 @@ EventPropagation SpinnerWidget::leftPressed(const int playerID)
{
setValue(m_value-1);
}
- else if (m_warp_around)
+ else if (m_wrap_around)
{
setValue(m_max);
}
diff --git a/src/modes/three_strikes_battle.cpp b/src/modes/three_strikes_battle.cpp
index 19e02264b..3cd89ed71 100644
--- a/src/modes/three_strikes_battle.cpp
+++ b/src/modes/three_strikes_battle.cpp
@@ -367,7 +367,7 @@ bool ThreeStrikesBattle::isRaceOver()
*/
void ThreeStrikesBattle::terminateRace()
{
- updateKartRanks();
+ updateKartRanks();
WorldWithRank::terminateRace();
} // terminateRace
diff --git a/src/states_screens/dialogs/gp_info_dialog.cpp b/src/states_screens/dialogs/gp_info_dialog.cpp
index 404f3fe25..05b963217 100644
--- a/src/states_screens/dialogs/gp_info_dialog.cpp
+++ b/src/states_screens/dialogs/gp_info_dialog.cpp
@@ -63,7 +63,7 @@ GPInfoDialog::GPInfoDialog(const std::string& gpIdent, const float w, const floa
// ---- GP Name
core::rect< s32 > area_top(0, 0, m_area.getWidth(), y1);
IGUIStaticText* title = GUIEngine::getGUIEnv()->addStaticText( translations->fribidize(gp->getName()),
- area_top, false, true, // border, word warp
+ area_top, false, true, // border, word wrap
m_irrlicht_window);
title->setTabStop(false);
title->setTextAlignment(EGUIA_CENTER, EGUIA_CENTER);
@@ -108,7 +108,7 @@ GPInfoDialog::GPInfoDialog(const std::string& gpIdent, const float w, const floa
widget->add();
// IGUIStaticText* line = GUIEngine::getGUIEnv()->addStaticText( lineText.c_str(),
- // entry_area, false , true , // border, word warp
+ // entry_area, false , true , // border, word wrap
// m_irrlicht_window);
}
diff --git a/src/states_screens/kart_selection.cpp b/src/states_screens/kart_selection.cpp
index a36c1790f..630cee074 100644
--- a/src/states_screens/kart_selection.cpp
+++ b/src/states_screens/kart_selection.cpp
@@ -315,7 +315,7 @@ public:
m_player_ident_spinner->m_properties[PROP_MAX_VALUE] =
StringUtils::toString(playerAmount-1);
m_player_ident_spinner->m_properties[PROP_ID] = spinnerID;
- m_player_ident_spinner->m_properties[PROP_WARP_AROUND] = "true";
+ m_player_ident_spinner->m_properties[PROP_WRAP_AROUND] = "true";
//m_player_ident_spinner->m_event_handler = this;
m_children.push_back(m_player_ident_spinner);
diff --git a/src/states_screens/options_screen_ui.cpp b/src/states_screens/options_screen_ui.cpp
index 006af7182..d621aacd5 100644
--- a/src/states_screens/options_screen_ui.cpp
+++ b/src/states_screens/options_screen_ui.cpp
@@ -63,7 +63,7 @@ void OptionsScreenUI::loadedFromFile()
GUIEngine::SpinnerWidget* skinSelector = getWidget("skinchoice");
assert( skinSelector != NULL );
- skinSelector->m_properties[PROP_WARP_AROUND] = "true";
+ skinSelector->m_properties[PROP_WRAP_AROUND] = "true";
m_skins.clear();
skinSelector->clearLabels();
diff --git a/src/guiengine/widgets/spinner_widget.hpp b/src/guiengine/widgets/spinner_widget.hpp
index 7dfd80032..51733127e 100644
--- a/src/guiengine/widgets/spinner_widget.hpp
+++ b/src/guiengine/widgets/spinner_widget.hpp
@@ -69,8 +69,8 @@ namespace GUIEngine
*/
bool m_gauge;
- /** \brief Whether to warp back to the first value when going "beyond" the last value */
- bool m_warp_around;
+ /** \brief Whether to wrap back to the first value when going "beyond" the last value */
+ bool m_wrap_around;
/** \brief implementing method from base class Widget */
virtual EventPropagation transmitEvent(Widget* w,